@@ -16,6 +16,7 @@
 #import "VLCHTTPUploaderController.h"
 #import "VLCSiriRemoteGestureRecognizer.h"
 #import "VLCNetworkImageView.h"
+#import "VLCMetaData.h"
 
 typedef NS_ENUM(NSInteger, VLCPlayerScanState)
 {
@@ -215,10 +216,6 @@ typedef NS_ENUM(NSInteger, VLCPlayerScanState)
         }
     }
 
-    if (!self.canScrub) {
-        return;
-    }
-
     switch (panGestureRecognizer.state) {
         case UIGestureRecognizerStateCancelled:
         case UIGestureRecognizerStateFailed:
@@ -231,10 +228,11 @@ typedef NS_ENUM(NSInteger, VLCPlayerScanState)
 
     UIView *view = self.view;
     CGPoint translation = [panGestureRecognizer translationInView:view];
+    BOOL canScrub = self.canScrub;
 
     if (!bar.scrubbing) {
         if (ABS(translation.x) > 150.0) {
-            if (self.isSeekable) {
+            if (self.isSeekable && canScrub) {
                 [self startScrubbing];
             } else {
                 return;
@@ -249,16 +247,17 @@ typedef NS_ENUM(NSInteger, VLCPlayerScanState)
         }
     }
 
+    if (!canScrub) {
+        return;
+    }
+
     [self showPlaybackControlsIfNeededForUserInteraction];
     [self setScanState:VLCPlayerScanStateNone];
 
-
     const CGFloat scaleFactor = 8.0;
-    CGFloat fractionInView = translation.x/CGRectGetWidth(view.bounds)/scaleFactor;
-
+    CGFloat fractionInView = translation.x / CGRectGetWidth(view.bounds) / scaleFactor;
     CGFloat scrubbingFraction = MAX(0.0, MIN(bar.scrubbingFraction + fractionInView,1.0));
 
-
     if (ABS(scrubbingFraction - bar.playbackFraction)<0.005) {
         scrubbingFraction = bar.playbackFraction;
     } else {
@@ -834,28 +833,25 @@ currentMediaHasTrackToChooseFrom:(BOOL)currentMediaHasTrackToChooseFrom
     }
 }
 
-- (void)displayMetadataForPlaybackController:(VLCPlaybackController *)controller
-                                       title:(NSString *)title
-                                     artwork:(UIImage *)artwork
-                                      artist:(NSString *)artist
-                                       album:(NSString *)album
-                                   audioOnly:(BOOL)audioOnly
+- (void)displayMetadataForPlaybackController:(VLCPlaybackController *)controller metadata:(VLCMetaData *)metadata
 {
+    NSString *title = metadata.title;
+    NSString *artist = metadata.artist;
+    NSString *albumName = metadata.albumName;
     self.titleLabel.text = title;
-
-    if (audioOnly) {
+    if (metadata.isAudioOnly) {
         self.audioArtworkImageView.image = nil;
         self.audioDescriptionTextView.hidden = YES;
         [self stopAudioDescriptionAnimation];
 
-        if (artist != nil && album != nil) {
+        if (artist != nil && albumName != nil) {
             [UIView animateWithDuration:.3 animations:^{
                 self.audioArtistLabel.text = artist;
                 self.audioArtistLabel.hidden = NO;
-                self.audioAlbumNameLabel.text = album;
+                self.audioAlbumNameLabel.text = albumName;
                 self.audioAlbumNameLabel.hidden = NO;
             }];
-            APLog(@"Audio-only track meta changed, tracing artist '%@' and album '%@'", artist, album);
+            APLog(@"Audio-only track meta changed, tracing artist '%@' and album '%@'", artist, albumName);
         } else if (artist != nil) {
             [UIView animateWithDuration:.3 animations:^{
                 self.audioArtistLabel.text = artist;
